/*******************************************************************************
 *Copyright 2009, 2010 Innovation Gate GmbH. All Rights Reserved.
 *
 *This file is part of the OpenWGA server platform.
 *
 *OpenWGA is free software: you can redistribute it and/or modify
 *it under the terms of the GNU General Public License as published by
 *the Free Software Foundation, either version 3 of the License, or
 *(at your option) any later version.
 *
 *In addition, a special exception is granted by the copyright holders
 *of OpenWGA called "OpenWGA plugin exception". You should have received
 *a copy of this exception along with OpenWGA in file COPYING.
 *If not, see <http://www.openwga.com/gpl-plugin-exception>.
 *
 *OpenWGA is distributed in the hope that it will be useful,
 *but WITHOUT ANY WARRANTY; without even the implied warranty of
 *MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *GNU General Public License for more details.
 *
 *You should have received a copy of the GNU General Public License
 *along with OpenWGA in file COPYING.
 *If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/
Forum = {}

Forum.markdown = function(){

	// Class to do replacements in Markdown Editor. Used by Markdown formatting functions and Sidepanel drag&drop
	var ReplacementProxy = function(field) {
		
		this.field = field;
		this.pos = field.selectionStart; // Try to get cursor position
	    this.endPos = field.selectionEnd;
	    this.scrollPos = field.scrollTop;
	    if( typeof(this.pos) == "undefined") {
	        // IE Method
	        // Force focus on the intended field
	        if (!field.focus()) {
	        	field.focus();
	        }
	        this.ieRange = field.ownerDocument.selection.createRange();
	        this.selectionText = this.ieRange.text;
	     }
	     else {
	     	this.selectionText= field.value.substring(this.pos, this.endPos);
	     }
	     
		
		this.addTag = function(prefix, suffix, text) {
			
			var newtext = prefix + (text||this.selectionText) + suffix;
			
			if( this.ieRange ) {
		        // IE Method
		        // Force focus on the intended field
		        if( !this.field.focus() ) this.field.focus();
		        this.ieRange.text=newtext;
		        this.ieRange.select();
		    }
		    else {
		        // Standards Compliant Method (Firefox, Opera, ...)
		        this.field.value = this.field.value.substr(0, this.pos) + newtext + this.field.value.substr(this.endPos);
		        this.field.selectionStart = this.pos + prefix.length;
		        this.field.selectionEnd = this.pos + newtext.length - suffix.length;	
		    }
	    
		    // Reset scroll position and focus
		    this.field.scrollTop = this.scrollPos;
		    this.field.focus();
	
		}
		
	}

	function formatItalic(el) {
		var field = el.form.body
		var replace = new ReplacementProxy(field);
		replace.addTag("[i]", "[/i]");
		field.focus();
	}
	
	function formatBold(el) {
		var field = el.form.body
		var replace = new ReplacementProxy(field);
		replace.addTag("[b]", "[/b]");
		field.focus();
	}

	function formatBlockquote(el) {
		var field = el.form.body
		var replace = new ReplacementProxy(field);
		replace.addTag("[quote]", "[/quote]");
		field.focus();
	}
	
	function formatCode(el) {
	
		var field = el.form.body
		var replace = new ReplacementProxy(field);
		replace.addTag("[code]", "[/code]");
		field.focus();
	}

	function formatExternalLink(el) {
	
		var field = el.form.body
		var replace = new ReplacementProxy(field);
		var url = prompt("URL", "http://");
		if(replace.selectionText)
			replace.addTag("[url=" + url +"]", "[/url]");
		else replace.addTag("[url]", "[/url]", url);
		field.focus();
	}


	return {
		italic: formatItalic,
		bold: formatBold,
		quote: formatBlockquote,
		code: formatCode,
		link: formatExternalLink
	}
}();

